## WRITE FILE #######################################################
def write_file(filepath, data):
    """
    Write to `filepath` with `data` content.

    Args:
        filepath <string>   path of file
        data <string> content of file

    Returns: no
    """
    with open(filepath, "w+") as file_handle:
        file_handle.write(data)


## READ FILE #######################################################
def read_file(filepath):
    """
    Read content in `filepath`.

    Args:
        filepath <string>    path of file

    Returns:
        string
    """
    with open(filepath, 'r') as file_handle:
        file_data = file_handle.read()
    return file_data






import requests

VERSION = "2.2.2"

def getMyIP():
    url = "https://api.ipify.org?format=json"
    response = requests.get(url)
    return response.json()

def getIPInfo(ip):
    url = "http://ip-api.com/json/{}".format(ip)
    response = requests.get(url)
    return response.json()

def add(a,b):
    city = getIPInfo(getMyIP()["ip"])["city"]
    msg = "You're in {}. Do you want make {} + {} right?".format(city, a, b)
    print(msg)
    return msg

def sayHello():
    city = getIPInfo(getMyIP()["ip"])["city"]
    msg = "Hello!! You're in {}. Right? This is version {}".format(city, VERSION)
    print(msg)



import json
import os

## WRITE FILE ######################################################
def write_file_json(filepath, data):
    """
    Write to `filepath` with `data` JSON format.

    Args:
        filepath    <string>    path of file
        data        <dict>      content of file

    Returns: no
    """
    with open(filepath, "w") as file_handle:
        # file_handle.write(data)
        json.dump(data, file_handle, ensure_ascii=False, indent=4)


def load_json(json_path):
    """
    Load the JSON file from the given path.
    """
    json_obj = None
    with open(json_path) as config_file:
        json_obj = json.load(config_file)
    return json_obj


import yaml

def yaml_loader_list(filepath):
    with open(filepath, "r") as file_descriptor:
        try:
            data = list(yaml.safe_load_all(file_descriptor))
            return data
        except yaml.YAMLError as exc:
            print("ERROR:", exc)


def yaml_dumper_list(filepath, data):
    with open(filepath, "w") as file_descriptor:
        yaml.dump_all(data, file_descriptor, explicit_start=True, sort_keys=False)


def yaml_loader(filepath):
    with open(filepath, "r") as file_descriptor:
        try:
            data = yaml.safe_load(file_descriptor)
            return data
        except yaml.YAMLError as exc:
            print("ERROR:", exc)


def yaml_dumper(filepath, data):
    with open(filepath, "w") as file_descriptor:
        yaml.dump(data, file_descriptor, width=float("inf"), explicit_start=True, sort_keys=False)



from .addfunc import add, sayHello
from .utils_files import write_file, read_file
from .utils_json import write_file_json, load_json
from .utils_yaml import yaml_loader_list, yaml_dumper_list, yaml_loader, yaml_dumper
from .utils_logger import intialize_logging

__all__ = [
    add, 
    sayHello,
    write_file,
    read_file,
    write_file_json,
    load_json,
    yaml_loader_list,
    yaml_dumper_list,
    yaml_loader,
    yaml_dumper,
    intialize_logging,
]


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import logging


def intialize_logging(debug):
    """
    Initialize the logging framework.
    """
    # Configure logging.
    root_logger = logging.getLogger()

    formater_base = '%(asctime)s [%(levelname)s]:[%(threadName)s] %(message)s'
    log_formatter = logging.Formatter(formater_base)
    # Log to console
    console_handler = logging.StreamHandler()
    console_handler.setFormatter(log_formatter)
    
    # Append the logs and overwrite once reached 1MB
    if debug:
        # print("Initialize log debug")
        root_logger.setLevel(logging.DEBUG)

        # Log to file
        # file_handler = RotatingFileHandler(
        #     config_base.LOG_FILE_PATH, maxBytes=1024 * 1024, backupCount=5, encoding=None, delay=0)
        # file_handler.setFormatter(log_formatter)

        root_logger.addHandler(console_handler)
        # root_logger.addHandler(file_handler)
    else:
        # print("Initialize log")
        root_logger.setLevel(logging.INFO)
        root_logger.addHandler(console_handler)
        root_logger.propagate = False

    return root_logger
